@@ -30,6 +30,7 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"regexp"
 	"strconv"
 	"strings"
 	"time"
@@ -184,22 +185,51 @@ func NodeAddToCluster(ctx context.Context, runtime runtimes.Runtime, node *k3d.N
 	l.Log().Tracef("Resulting node %+v", node)
 
 	k3sURLEnvFound := false
+	k3sURLEnvIndex := -1
 	k3sTokenEnvFoundIndex := -1
 	for index, envVar := range node.Env {
 		if strings.HasPrefix(envVar, k3s.EnvClusterConnectURL) {
 			k3sURLEnvFound = true
+			k3sURLEnvIndex = index
 		}
 		if strings.HasPrefix(envVar, k3s.EnvClusterToken) {
 			k3sTokenEnvFoundIndex = index
 		}
 	}
-	if !k3sURLEnvFound {
-		if url, ok := node.RuntimeLabels[k3d.LabelClusterURL]; ok {
-			node.Env = append(node.Env, fmt.Sprintf("%s=%s", k3s.EnvClusterConnectURL, url))
+
+	if checkK3SURLIsActive(cluster.Nodes, node.Env[k3sURLEnvIndex]) {
+		if !k3sURLEnvFound {
+			if url, ok := node.RuntimeLabels[k3d.LabelClusterURL]; ok {
+				node.Env = append(node.Env, fmt.Sprintf("%s=%s", k3s.EnvClusterConnectURL, url))
+			} else {
+				l.Log().Warnln("Failed to find K3S_URL value!")
+			}
+		}
+	} else {
+		// Use LB if available as registration url for nodes
+		// otherwise fallback to server node
+		var registrationNode *k3d.Node
+		serverLBNodes := util.FilterNodesByRole(cluster.Nodes, k3d.LoadBalancerRole)
+		if len(serverLBNodes) > 0 {
+			registrationNode = serverLBNodes[0]
 		} else {
-			l.Log().Warnln("Failed to find K3S_URL value!")
+			for _, existingNode := range cluster.Nodes {
+				if existingNode.Role == k3d.ServerRole {
+					registrationNode = existingNode
+					break
+				}
+			}
+		}
+
+		if !k3sURLEnvFound {
+			node.Env = append(node.Env, fmt.Sprintf("%s=https://%s:%s", k3s.EnvClusterConnectURL, registrationNode.Name, k3d.DefaultAPIPort))
+		} else {
+			if !checkK3SURLIsActive(cluster.Nodes, node.Env[k3sURLEnvIndex]) {
+				node.Env[k3sURLEnvIndex] = fmt.Sprintf("%s=https://%s:%s", k3s.EnvClusterConnectURL, registrationNode.Name, k3d.DefaultAPIPort)
+			}
 		}
 	}
+
 	if k3sTokenEnvFoundIndex != -1 && createNodeOpts.ClusterToken != "" {
 		l.Log().Debugln("Overriding copied cluster token with value from nodeCreateOpts...")
 		node.Env[k3sTokenEnvFoundIndex] = fmt.Sprintf("%s=%s", k3s.EnvClusterToken, createNodeOpts.ClusterToken)
@@ -648,7 +678,7 @@ func NodeDelete(ctx context.Context, runtime runtimes.Runtime, node *k3d.Node, o
 		}
 
 		// if it's a server node, then update the loadbalancer configuration
-		if node.Role == k3d.ServerRole {
+		if node.Role == k3d.ServerRole && cluster.ServerLoadBalancer != nil {
 			if err := UpdateLoadbalancerConfig(ctx, runtime, cluster); err != nil {
 				if !errors.Is(err, ErrLBConfigHostNotFound) {
 					return fmt.Errorf("failed to update cluster loadbalancer: %w", err)
@@ -683,10 +713,33 @@ func patchServerSpec(node *k3d.Node, runtime runtimes.Runtime) error {
 	node.RuntimeLabels[k3d.LabelServerAPIPort] = node.ServerOpts.KubeAPI.Binding.HostPort
 
 	node.Args = append(node.Args, "--tls-san", node.RuntimeLabels[k3d.LabelServerAPIHost]) // add TLS SAN for non default host name
+	if node.RuntimeLabels[k3d.LabelServerLoadBalancer] != "" {
+		// add TLS SAN for server loadbalancer
+		node.Args = append(node.Args, "--tls-san", node.RuntimeLabels[k3d.LabelServerLoadBalancer])
+	}
 
 	return nil
 }
 
+// Check if node associated with K3S URL value is still active in the cluster
+func checkK3SURLIsActive(nodes []*k3d.Node, k3sURL string) bool {
+	// extract the node name
+	re := regexp.MustCompile("K3S_URL=https?://([a-zA-Z0-9_.-]+)")
+	match := re.FindStringSubmatch(k3sURL)
+
+	if match == nil {
+		return false
+	}
+
+	for _, node := range nodes {
+		if node.Name == match[1] {
+			return true
+		}
+	}
+
+	return false
+}
+
 // NodeList returns a list of all existing clusters
 func NodeList(ctx context.Context, runtime runtimes.Runtime) ([]*k3d.Node, error) {
 	nodes, err := runtime.GetNodesByLabel(ctx, k3d.DefaultRuntimeLabels)
